==> fans-common-core-1.0.7-sources.jar: com/ptteng/sca/fans/common/client/ProductionRecordSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.fans.common.client;

import java.util.List;
import java.util.Map;

import com.ptteng.fans.common.model.ProductionRecord;
import com.ptteng.fans.common.service.ProductionRecordService;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;

public class ProductionRecordSCAClient implements ProductionRecordService {

    private ProductionRecordService productionRecordService;

	public ProductionRecordService getProductionRecordService() {
		return productionRecordService;
	}
	
	
	public void setProductionRecordService(ProductionRecordService productionRecordService) {
		this.productionRecordService =productionRecordService;
	}
	
	
			   
		@Override
		public Long insert(ProductionRecord productionRecord)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.insert(productionRecord);
		          
		
		}	
		  
    	   
		@Override
		public List<ProductionRecord> insertList(List<ProductionRecord> productionRecordList)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.insertList(productionRecordList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(ProductionRecord productionRecord)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.update(productionRecord);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<ProductionRecord> productionRecordList)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.updateList(productionRecordList);
		          
		
		}	
		  
    	   
		@Override
		public ProductionRecord getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<ProductionRecord> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getProductionRecordIdsByProductionId(Long productionId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.getProductionRecordIdsByProductionId(productionId,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countProductionRecordIdsByProductionId(Long productionId)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.countProductionRecordIdsByProductionId(productionId);
	
	
	}
	
		
	
		@Override
	public List<Long> getProductionRecordIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return productionRecordService.getProductionRecordIds(start, limit);
	}

	@Override
	public Integer countProductionRecordIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return productionRecordService.countProductionRecordIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return productionRecordService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return productionRecordService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   productionRecordService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.productionRecordService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}

==> fans-common-core-1.1.4-sources.jar: com/ptteng/sca/fans/common/client/ProductionRecordSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.fans.common.client;

import java.util.List;
import java.util.Map;

import com.ptteng.fans.common.model.ProductionRecord;
import com.ptteng.fans.common.service.ProductionRecordService;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;

public class ProductionRecordSCAClient implements ProductionRecordService {

    private ProductionRecordService productionRecordService;

	public ProductionRecordService getProductionRecordService() {
		return productionRecordService;
	}
	
	
	public void setProductionRecordService(ProductionRecordService productionRecordService) {
		this.productionRecordService =productionRecordService;
	}
	
	
			   
		@Override
		public Long insert(ProductionRecord productionRecord)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.insert(productionRecord);
		          
		
		}	
		  
    	   
		@Override
		public List<ProductionRecord> insertList(List<ProductionRecord> productionRecordList)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.insertList(productionRecordList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(ProductionRecord productionRecord)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.update(productionRecord);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<ProductionRecord> productionRecordList)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.updateList(productionRecordList);
		          
		
		}	
		  
    	   
		@Override
		public ProductionRecord getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<ProductionRecord> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getProductionRecordIdsByProductionId(Long productionId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.getProductionRecordIdsByProductionId(productionId,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countProductionRecordIdsByProductionId(Long productionId)throws ServiceException, ServiceDaoException{
		
		return productionRecordService.countProductionRecordIdsByProductionId(productionId);
	
	
	}
	
		
	
		@Override
	public List<Long> getProductionRecordIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return productionRecordService.getProductionRecordIds(start, limit);
	}

	@Override
	public Integer countProductionRecordIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return productionRecordService.countProductionRecordIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return productionRecordService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return productionRecordService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   productionRecordService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.productionRecordService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}

    @Override
    public Object getMapListByDynamicCondition(Class clz,Map<String, Object> conditions, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
        return this.productionRecordService.getMapListByDynamicCondition(clz, conditions, start, limit);
    }


}
